Generic request wrapper for making simple web service requests Will return parsed results, even if they are an error description sent by the API Will stop() if the request fails into an error different from 400
.doRequest(
self,
url = "",
filters = list(),
getInfo = FALSE,
rawResponse = FALSE
)Calling object
Full URL to make the request, without GET parameters
GET parameters
When TRUE, will return a list with ("response", "duration", "status"), where "duration" is the time the request took and "status" is the HTTP response status
When TRUE, the response returned is the unparsed object returned by httr::GET, otherwise a parsed named list is returned
(list) The parsed response