Public wrapper that lets a user download data products manually with a runId Can optionally return just the download links
.downloadDataProduct(
self,
runId = 0,
maxRetries = 0,
downloadResultsOnly = FALSE,
includeMetadataFile = TRUE,
overwrite = FALSE
)Calling object
(numeric) Run ID as provided by runDataProduct()
(numeric) Maximum number of API requests allowed, 0 for no limit
(logical) When TRUE, files are not downloaded By default (FALSE) generated files are downloaded
(logical) When TRUE, a metadata file is downloaded, otherwise it is skipped
(logical) When TRUE downloaded files will overwrite any file with the same filename, otherwise they will be skipped
(list) A list of results (one named list for each file) with information on the operation outcome