Download all data product files for provided run id
.downloadProductFiles(
self,
runId = 0,
getMetadata = TRUE,
maxRetries = 0,
overwrite = TRUE,
fileCount = 0
)Caling object
Run id returned by .runDataProduct()
When TRUE, the metadata file will be downloaded
(numeric) Maximum number of API requests allowed, 0 for no limit
(logical) When TRUE downloaded files will overwrite any file with the same filename, otherwise they will be skipped
The number of files to download, or 0 if unknown
a list of named lists, with the results for each file