Sets a poll period adequate to the estimated processing time Longer processing times require longer poll periods to avoid going over maxRetries
.estimatePollPeriod(self, response)Calling object
Response obtained in .requestDataProduct() for the DP request
(numeric) suggested time between server polls (seconds)