Filter file list results to only those where the filename ends with the extension If extension is empty no change will be made
.filterByExtension(self, results = list(), extension = "")Calling object
Results as otained by getListByLocation() or getListByDevice()
(character) Extension to search for (i.e. "txt")
Filtered list