Aggregates individual download results obtained in .orderDataProduct() into a list of formatted results to return, and a named list with general stats of the operation
.formatResult(self, fileList = list(), runInfo = list())Calling object
List of individual download results
As returned by .runDataProduct()
A named list with "downloadResults" (list of download results) and "stats" (general stats for the full operation)