Learn R Programming

onc.api (version 2.0.1.0)

.getDataProducts: Request a list of data products that matches the filters provided

Description

Request a list of data products that matches the filters provided

Usage

.getDataProducts(self, filters = list())

Arguments

self

Calling object

filters

(named list) search filters

Value

   (named list) A list of data products found, or an error description if any