Learn R Programming

onc.api (version 2.0.1.0)

.getDeployments: Request a list of deployments that matches the filters provided

Description

Request a list of deployments that matches the filters provided

Usage

.getDeployments(self, filters = list())

Arguments

self

Calling object

filters

(named list) search filters

Value

   (named list) A list of deployments found, or an error description if any