Learn R Programming

onc.api (version 2.0.1.0)

.getDevices: Request a list of devices that matches the filters provided

Description

Request a list of devices that matches the filters provided

Usage

.getDevices(self, filters = list())

Arguments

self

Calling object

filters

(named list) search filters

Value

   (named list) A list of devices found, or an error description if any