A generic wrapper for getListByLocation() and getListByDevice()
.getList(self, filters = list(), by = "location", allPages = FALSE)Calling object
(named list) describe the data origin
One of: "location", "device"
When TRUE, if the data is too long to fit a single request, multiple pages will be requested until all data is obatined
(named list) Information on the list of files obtained