Get a list of files available in Oceans 2.0 Archiving System for a given device code. The list of filenames can be filtered by time range. filtered by others optional parameters.
.getListByDevice(self, filters = list(), allPages = FALSE)Calling object
(named list) describe the data origin
When TRUE, if the data is too long to fit a single request, multiple pages will be requested until all data is obatined
(named list) file list obtained