Get a list of files for a given location code and device category code, and filtered by others optional parameters.
.getListByLocation(self, filters = list(), allPages = FALSE)Calling object
(named list) describe the data origin
When TRUE, if the data is too long to fit a single request, multiple pages will be requested until all data is obatined
(named list) file list obtained