Learn R Programming

onc.api (version 2.0.1.0)

.getLocationHierarchy: Request a hierarchical tree list of locations that matches the filters provided

Description

Request a hierarchical tree list of locations that matches the filters provided

Usage

.getLocationHierarchy(self, filters = list())

Arguments

self

Calling object

filters

(named list) search filters

Value

   (named list) A list of locations found, or an error description if any
           Locations include lists of children locations recursively