Learn R Programming

onc.api (version 2.0.1.0)

.getLocations: Request a list of locations that matches the filters provided

Description

Request a list of locations that matches the filters provided

Usage

.getLocations(self, filters = list())

Arguments

self

Calling object

filters

(named list) search filters

Value

   (named list) A list of locations found, or an error description if any