Returns a list of information lists for each file available for download Returned rows will have the same structure as those returned by DataProductFile$getInfo()
.infoForProductFiles(self, dpRunId = 0, fileCount = 0, getMetadata = FALSE)Caling object
Run id returned by .runDataProduct()
The number of files to download, or 0 if unknown
When TRUE, the metadata file will be included
a list of named lists, with the results for each file