Request, run and download a data product as described by the filters
.orderDataProduct(
self,
filters = list(),
maxRetries = 0,
downloadResultsOnly = FALSE,
metadata = TRUE,
overwrite = FALSE
)Caling object
(named list) Filters that describe this data product
(numeric) Total maximum number of request calls allowed, 0 for no limit
(logical) When TRUE, files are not downloaded By default (FALSE) generated files are downloaded
(logical) When TRUE, a metadata file is downloaded, otherwise it is skipped
(logical) When TRUE downloaded files will overwrite any file with the same filename, otherwise they will be skipped
(list) A list of results (one named list for each file) with information on the operation outcome