Pretty prints a complex hierarchy of lists
.prettyPrint(item, name = "", level = 0, comma = FALSE, file = "")Hierarchy item (can be a list or an atomic element)
(character) Item name if its an element in a named list
(numeric) Depth level in the hierarchy, starting at 0
(logical) If TRUE, a comma is printed after this element
A file connection to an open file if we should print to it, or "" (no file, print to console)