.print: Helper for printing a JSON named list to the console
Can alternatively print the output to a text file at filePath
Description
Helper for printing a JSON named list to the console
Can alternatively print the output to a text file at filePath
Usage
.print(self, obj, filePath = "")
Arguments
obj
named list to print (usually the result of another function)
filePath
(string) if present, creates the file and writes the output in it