.sanitizeBooleans: For all rows in data, enforce that fields expected to have bool values
are logical values (fixes API issues with booleans returned as strings)
Description
For all rows in data, enforce that fields expected to have bool values
are logical values (fixes API issues with booleans returned as strings)
Usage
.sanitizeBooleans(self, data = list())
Value
(list) The modified data