.getDataProducts: Request a list of data products that matches the filters provided
Description
Request a list of data products that matches the filters provided
Usage
.getDataProducts(self, filters = list())
Arguments
filters
(named list) search filters
Value
(named list) A list of data products found, or an error description if any