.getDevices: Request a list of devices that matches the filters provided
Description
Request a list of devices that matches the filters provided
Usage
.getDevices(self, filters = list())
Arguments
filters
(named list) search filters
Value
(named list) A list of devices found, or an error description if any