.getLocationHierarchy: Request a hierarchical tree list of locations that matches the filters provided
Description
Request a hierarchical tree list of locations that matches the filters provided
Usage
.getLocationHierarchy(self, filters = list())
Arguments
filters
(named list) search filters
Value
(named list) A list of locations found, or an error description if any
Locations include lists of children locations recursively