.getLocations: Request a list of locations that matches the filters provided
Description
Request a list of locations that matches the filters provided
Usage
.getLocations(self, filters = list())
Arguments
filters
(named list) search filters
Value
(named list) A list of locations found, or an error description if any